@@ -154,9 +154,10 @@ resfiles = [
 	"ref/ClayRGB1998.gam",
 	"ref/sRGB.gam",
 	"ref/verify_extended.ti1",
-	"ti1/d3-e4-s2-g25-m0-b0-f0.ti1",
-	"ti1/d3-e4-s3-g49-m3-b0-f0.ti1",
-	"ti1/d3-e4-s5-g49-m5-b0-f0.ti1",
+	"ti1/d3-e4-s2-g28-m0-b0-f0.ti1",
+	"ti1/d3-e4-s3-g52-m3-b0-f0.ti1",
+	"ti1/d3-e4-s4-g52-m4-b0-f0.ti1",
+	"ti1/d3-e4-s5-g52-m5-b0-f0.ti1",
 	"xrc/extra.xrc",
 	"xrc/gamap.xrc",
 	"xrc/main.xrc",
@@ -719,9 +720,10 @@ valid_values = {
 	"tc_algo": ["", "t", "r", "R", "q", "Q", "i", "I"],  # Q = Argyll >= 1.1.0
 	"tc_vrml_use_D50": [0, 1],
 	"tc_vrml_cie_colorspace": ["DIN99", "DIN99b", "DIN99c", "DIN99d", "ICtCp",
-							   "LCH(ab)", "LCH(uv)", "Lab", "Luv", "Lu'v'", "xyY"],
+							   "IPT", "LCH(ab)", "LCH(uv)", "Lab", "Lpt", "Luv",
+							   "Lu'v'", "xyY"],
 	"tc_vrml_device_colorspace": ["HSI", "HSL", "HSV", "RGB"],
-	"testchart.auto_optimize": [0, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18],
+	"testchart.auto_optimize": range(19),
 	"testchart.patch_sequence": ["optimize_display_response_delay",
 								 "maximize_lightness_difference",
 								 "maximize_rec709_luma_difference",
@@ -775,6 +777,7 @@ defaults = {
 	"3dlut.enable": 1,
 	"3dlut.output.profile": "",
 	"3dlut.output.profile.apply_cal": 1,
+	"3dlut.preserve_sync": 0,
 	"3dlut.rendering_intent": "aw",
 	"3dlut.use_abstract_profile": 0,
 	"3dlut.size": 65,
@@ -856,7 +859,7 @@ defaults = {
 	"gamap_saturation_intent": "s",
 	"gamap_default_intent": "p",
 	"gamma": 2.2,
-	"iccgamut.surface_detail": 6.0,
+	"iccgamut.surface_detail": 10.0,
 	"instruments": "",
 	"last_launch": "99",
 	"log.autoshow": 0,
@@ -935,6 +938,7 @@ defaults = {
 	"position.tcgen.x": 50,
 	"position.tcgen.y": 50,
 	"profile.black_point_compensation": 0,
+	"profile.black_point_correction": 0.0,
 	"profile.create_gamut_views": 1,
 	"profile.install_scope": "l" if (sys.platform != "win32" and 
 									 os.geteuid() == 0) # or 
@@ -1000,6 +1004,7 @@ defaults = {
 	"profile_loader.known_window_classes": ";".join(["CalClient.exe"]),
 	"profile_loader.quantize_bits": 16,
 	"profile_loader.reset_gamma_ramps": 0,
+	"profile_loader.track_other_processes": 1,
 	"profile_loader.use_madhcnet": 0,
 	"profile_loader.verify_calibration": 0,
 	"recent_cals": "",
